@@ -7,5 +7,8 @@ MYBASE = declarative_base()
 class WasPosted(MYBASE):
     '''WasPosted mapping for SQLAlchemy'''
     __tablename__ = 'wasposted'
-    tweet = Column(String, primary_key=True)
+    twid = Column(Integer, primary_key=True)
+    tweet = Column(String, unique=True)
+    tweetimage = Column(String, unique=False)
     lastinsertid = Column(Integer)
+    lastcircled = Column(Boolean, default=False)
